==> geometa_0.6-4.tar.gz: geometa/R/ISOApplicationSchemaInformation.R <==
#' ISOApplicationSchemaInformation
#'
#' @docType class
#' @importFrom R6 R6Class
#' @export
#' @keywords ISO application schema information
#' @return Object of \code{\link{R6Class}} for modelling an ISO ApplicationSchemaInformation
#' @format \code{\link{R6Class}} object.
#'
#' @field name [\code{\link{ISOCitation}}]
#' @field schemaLanguage [\code{\link{character}}]
#' @field constraintLanguage [\code{\link{character}}]
#' @field schemaAscii [\code{\link{character}}]
#' @field graphicsFile [\code{\link{ISOBinary}}]
#' @field softwareDevelopmentFile [\code{\link{ISOBinary}}]
#' @field softwareDevelopmentFileFormat [\code{\link{character}}]
#'
#' @section Methods:
#' \describe{
#'  \item{\code{new(xml)}}{
#'    This method is used to instantiate an \code{\link{ISOApplicationSchemaInformation}}
#'  }
#'  \item{\code{setName(name)}}{
#'    Sets name, object of class \code{\link{ISOCitation}}
#'  }
#'  \item{\code{setSchemaLanguage(schemaLanguage)}}{
#'    Sets schema language
#'  }
#'  \item{\code{setConstraintLanguage(constraintLanguage)}}{
#'    Sets constraint language
#'  }
#'  \item{\code{setSchemaAscii(schemaAscii)}}{
#'    Sets schema Ascii
#'  }
#'  \item{\code{setGraphicsFile(graphicsFile)}}{
#'    Sets graphics file
#'  }
#'  \item{\code{setSoftwareDevelopmentFile(file)}}{
#'    Sets software development file
#'  }
#'  \item{\code{setSoftwareDevelopmentFileFormat(format)}}{
#'    Sets software development file format
#'  }
#' }
#' 
#' @references 
#'   ISO 19115:2003 - Geographic information -- Metadata 
#' 
#' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
#'
ISOApplicationSchemaInformation <- R6Class("ISOApplicationSchemaInformation",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_ApplicationSchemaInformation",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
     
     #name [1..1]
     name = NULL,
     #schemaLanguage [1..1]
     schemaLanguage = NULL,
     #constraintLanguage [1..1]  
     constraintLanguage = NULL,
     #schemaAscii [0..1]
     schemaAscii = NULL,
     #graphicsFile [0..1] 
     graphicsFile = NULL,
     #softwareDevelopmentFile [0..1]
     softwareDevelopmentFile = NULL,
     #softwareDevelopmentFileFormat [0..1]
     softwareDevelopmentFileFormat = NULL,
    
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
     
     #setName
     setName = function(name){
       if(!is(name, "ISOCitation")){
         stop("The argument 'name' should be an object of class 'ISOCitation")
       }
       self$name <- name
     },
     
     #setSchemaLanguage
     setSchemaLanguage = function(schemaLanguage){
       self$schemaLanguage <- schemaLanguage
     },
     
     #setConstraintLanguage
     setConstraintLanguage = function(constraintLanguage){
       self$constraintLanguage <- constraintLanguage
     },
     
     #setSchemaAscii
     setSchemaAscii = function(schemaAscii){
       self$schemaAscii <- schemaAscii
     },
     
     #setGraphicsFile
     setGraphicsFile = function(graphicsFile){
       self$graphicsFile <- ISOBinary$new(value = graphicsFile)
     },
     
     #setSoftwareDevelopmentFile
     setSoftwareDevelopmentFile = function(file){
       self$softwareDevelopmentFile <- ISOBinary$new(value = file)
     },
     
     #setSoftwareDevelopmentFileFormat
     setSoftwareDevelopmentFileFormat = function(format){
       self$softwareDevelopmentFileFormat <- format
     }
   )                        
)

==> geometa_0.7-1.tar.gz: geometa/R/ISOApplicationSchemaInformation.R <==
#' ISOApplicationSchemaInformation
#'
#' @docType class
#' @importFrom R6 R6Class
#' @export
#' @keywords ISO application schema information
#' @return Object of \code{\link{R6Class}} for modelling an ISO ApplicationSchemaInformation
#' @format \code{\link{R6Class}} object.
#' 
#' @references 
#'   ISO 19115:2003 - Geographic information -- Metadata 
#' 
#' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
#'
ISOApplicationSchemaInformation <- R6Class("ISOApplicationSchemaInformation",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_ApplicationSchemaInformation",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
     
     #'@field name name [1..1]
     name = NULL,
     #'@field schemaLanguage chemaLanguage [1..1]
     schemaLanguage = NULL,
     #'@field constraintLanguage constraintLanguage [1..1]  
     constraintLanguage = NULL,
     #'@field schemaAscii schemaAscii [0..1]
     schemaAscii = NULL,
     #'@field graphicsFile graphicsFile [0..1] 
     graphicsFile = NULL,
     #'@field softwareDevelopmentFile softwareDevelopmentFile [0..1]
     softwareDevelopmentFile = NULL,
     #'@field softwareDevelopmentFileFormat softwareDevelopmentFileFormat [0..1]
     softwareDevelopmentFileFormat = NULL,
    
     #'@description Initializes object
     #'@param xml object of class \link{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
     
     #'@description Set name
     #'@param name name
     setName = function(name){
       if(!is(name, "ISOCitation")){
         stop("The argument 'name' should be an object of class 'ISOCitation")
       }
       self$name <- name
     },
     
     #'@description Set schema language
     #'@param schemaLanguage schema language
     setSchemaLanguage = function(schemaLanguage){
       self$schemaLanguage <- schemaLanguage
     },
     
     #'@description Set constraint language
     #'@param constraintLanguage constraint language
     setConstraintLanguage = function(constraintLanguage){
       self$constraintLanguage <- constraintLanguage
     },
     
     #'@description Set schema Ascii
     #'@param schemaAscii schema Ascii
     setSchemaAscii = function(schemaAscii){
       self$schemaAscii <- schemaAscii
     },
     
     #'@description Set graphics file
     #'@param graphicsFile graphics file
     setGraphicsFile = function(graphicsFile){
       self$graphicsFile <- ISOBinary$new(value = graphicsFile)
     },
     
     #'@description Set software development file
     #'@param file file
     setSoftwareDevelopmentFile = function(file){
       self$softwareDevelopmentFile <- ISOBinary$new(value = file)
     },
     
     #'@description Set software development file format
     #'@param format file format
     setSoftwareDevelopmentFileFormat = function(format){
       self$softwareDevelopmentFileFormat <- format
     }
   )                        
)
